Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
tests / test_beetle.py | TestBeetle.test_added_metadata |  | 29% | 7 | 5 | 0 |  | 0% | 2 | 0 |  | 22%
Total |  |  | 97% | 197 | 5 | 0 |  | 50% | 4 | 0 |  | 97%

No items found using the specified filter.

30 functions skipped due to complete coverage.